"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ContentModel;
(function (ContentModel) {
    ContentModel[ContentModel["TEXT"] = 1] = "TEXT";
    ContentModel[ContentModel["SCRIPT"] = 2] = "SCRIPT";
})(ContentModel = exports.ContentModel || (exports.ContentModel = {}));
class Context {
    constructor(source) {
        this.state = undefined;
        this.string = source.data;
        this.filename = source.filename;
        this.line = 1;
        this.column = 1;
        this.contentModel = ContentModel.TEXT;
        this.scriptEnd = undefined;
    }
    consume(n, state) {
        if (typeof n !== 'number') {
            n = n[0].length;
        }
        let consumed = this.string.slice(0, n);
        let offset;
        while ((offset = consumed.indexOf('\n')) >= 0) {
            this.line++;
            this.column = 1;
            consumed = consumed.substr(offset + 1);
        }
        this.column += consumed.length;
        this.string = this.string.substr(n);
        if (typeof state !== 'undefined') {
            this.state = state;
        }
    }
    getLocation() {
        return {
            filename: this.filename,
            line: this.line,
            column: this.column,
        };
    }
    getLocationString() {
        return `${this.filename}:${this.line}:${this.column}`;
    }
}
exports.Context = Context;
exports.default = Context;
