"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lexer_1 = require("lexer");
const chai = require('chai');
chai.use(require('chai-subset'));
chai.use(function (chai, utils) {
    function expectValid() {
        const report = utils.flag(this, 'object');
        if (!report.valid) {
            const actual = report.results[0].messages[0].message;
            new chai.Assertion(actual, 'Result should not contain error').to.be.undefined;
        }
        new chai.Assertion(report.valid, 'Result should be successful').to.be.true;
    }
    function expectInvalid() {
        const report = utils.flag(this, 'object');
        new chai.Assertion(report.valid, 'Result should be failure').to.be.false;
    }
    function expectError(expectedRule, expectedMessage) {
        const report = utils.flag(this, 'object');
        new chai.Assertion(report.results, 'Result should contain an error').to.have.lengthOf(1);
        const actual = report.results[0].messages[0];
        new chai.Assertion(actual.ruleId).to.be.equal(expectedRule);
        if (expectedMessage instanceof RegExp) {
            new chai.Assertion(actual.message).to.match(expectedMessage);
        }
        else {
            new chai.Assertion(actual.message).to.be.equal(expectedMessage);
        }
    }
    function expectToken(expected) {
        const actual = utils.flag(this, 'object').value;
        if (expected.type) {
            new chai.Assertion(lexer_1.TokenType[actual.type]).to.be.equal(lexer_1.TokenType[expected.type]);
        }
        new chai.Assertion(actual).to.containSubset(expected);
    }
    chai.Assertion.addProperty('valid', expectValid);
    chai.Assertion.addProperty('invalid', expectInvalid);
    chai.Assertion.addMethod('error', expectError);
    chai.Assertion.addMethod('token', expectToken);
});
