"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pattern_1 = require("./pattern");
describe('Pattern', function () {
    const expect = require('chai').expect;
    it('kebabcase should match strings with dashes', function () {
        const pattern = pattern_1.parsePattern('kebabcase');
        expect('foo-bar').to.match(pattern);
        expect('fooBar').to.not.match(pattern);
        expect('Foobar').to.not.match(pattern);
        expect('foo_bar').to.not.match(pattern);
    });
    it('camelcase should match strings in camelcase', function () {
        const pattern = pattern_1.parsePattern('camelcase');
        expect('foo-bar').to.not.match(pattern);
        expect('fooBar').to.match(pattern);
        expect('Foobar').to.not.match(pattern);
        expect('foo_bar').to.not.match(pattern);
    });
    it('underscore should match strings with underscore', function () {
        const pattern = pattern_1.parsePattern('underscore');
        expect('foo-bar').to.not.match(pattern);
        expect('fooBar').to.not.match(pattern);
        expect('Foobar').to.not.match(pattern);
        expect('foo_bar').to.match(pattern);
    });
    it('should support user-supplied regexp', function () {
        const pattern = pattern_1.parsePattern('^foo-[a-z]\\w+$');
        expect('foo-bar').to.match(pattern);
        expect('bar-foo').to.not.match(pattern);
        expect('barfoo-baz').to.not.match(pattern);
    });
});
