"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
class Reporter {
    constructor() {
        this.result = {};
    }
    static merge(reports) {
        const valid = reports.every(report => report.valid);
        const merged = {};
        reports.forEach((report) => {
            report.results.forEach((result) => {
                const key = result.filePath;
                if (merged.hasOwnProperty(key)) {
                    merged[key].messages = [].concat(merged[key].messages, result.messages);
                }
                else {
                    merged[key] = Object.assign({}, result);
                }
            });
        });
        return { valid, results: Object.keys(merged).map(key => merged[key]) };
    }
    add(node, rule, message, severity, context) {
        if (!this.result.hasOwnProperty(context.filename)) {
            this.result[context.filename] = [];
        }
        this.result[context.filename].push({
            ruleId: rule.name,
            severity,
            message,
            line: context.line,
            column: context.column,
        });
    }
    addManual(filename, message) {
        if (!this.result.hasOwnProperty(filename)) {
            this.result[filename] = [];
        }
        this.result[filename].push(message);
    }
    save() {
        return {
            valid: Object.keys(this.result).length === 0,
            results: Object.keys(this.result).map(filePath => {
                const messages = [].concat(this.result[filePath]).sort(messageSort);
                return {
                    filePath,
                    messages,
                    errorCount: messages.filter(m => m.severity === config_1.Config.SEVERITY_ERROR).length,
                    warningCount: messages.filter(m => m.severity === config_1.Config.SEVERITY_WARN).length,
                };
            }),
        };
    }
}
exports.Reporter = Reporter;
function messageSort(a, b) {
    if (a.line < b.line) {
        return -1;
    }
    if (a.line > b.line) {
        return 1;
    }
    if (a.column < b.column) {
        return -1;
    }
    if (a.column > b.column) {
        return 1;
    }
    return 0;
}
exports.default = Reporter;
